@@ -22,7 +22,4 @@ def get_params(function_info, args, kwargs):
     for arg in function_info["args_to_ignore"]:
         params.pop(arg, None)
 
-    # if it's a method we don't want to serialize the instance
-    params.pop("self", None)
-
     return params
\ No newline at end of file
