@@ -2,6 +2,9 @@
 import re
 
 def parse_time(value):
+    if value is None:
+        return None
+
     if type(value) in [int, float]:
         if value >= 0:
             return value
@@ -13,7 +16,7 @@ def parse_time(value):
         return None
         
     if not re.match(r"\d+[smhdw]", value):
-        raise ValueError("The time delta %s does not match the regex \d+[smhdw]"%value)
+        raise ValueError("The time delta %s does not match the regex \\d+[smhdw]"%value)
     
     number = int(value[:-1])
     unit = value[-1]
